==> gspiceui_0.9.65.dfsg.orig.tar.gz: gspiceui-0.9.65.dfsg/src/process/PrcGaw.hpp <==
//*****************************************************************************
//                                   PrcGaw.hpp                               *
//                                  ------------                              *
//  Description : Provides an interface to the utility gaw which is a         *
//                waveform viewer. The user can view the raw simulation data  *
//                or envoke this utility which plots the data graphically.    *
//  Started     : 10/01/2008                                                  *
//  Last Update : 22/01/2008                                                  *
//  Copyright   : (C) 2008 by MSWaters                                        *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef PRCGAW_HPP
#define PRCGAW_HPP

// System Includes

using  namespace  std;

#include <iostream>

// wxWindows Includes

#include <wx/wx.h>
#include <wx/tokenzr.h>

// Application Includes

#include "base/PrcBase.hpp"

// Local Constant Declarations


//*****************************************************************************

class PrcGaw : public PrcBase
{
  private:

    wxFileName  m_ofnResults; // The full simulator results file name

    // Functions for reformatting the results file for input to the viewer
    bool  bFormatFile ( void );
    bool  bFormatLine ( wxString & rosLine );
    bool  bFormatField( wxString & rosField );

  public:

    PrcGaw( void );
   ~PrcGaw( );

    bool  bSetResults( const wxString & rosFileName );

    const wxFileName & roGetResults( void ) { return( m_ofnResults ); }

    bool  bExec( void );
};

//*****************************************************************************

#endif // PRCGAW_HPP

==> gspiceui_0.9.98.dfsg.orig.tar.gz: gspiceui-0.9.98.dfsg/src/process/PrcGaw.hpp <==
//*****************************************************************************
//                                   PrcGaw.hpp                               *
//                                  ------------                              *
//  Description : Provides an interface to the utility gaw which is a         *
//                waveform viewer. The user can view the raw simulation data  *
//                or envoke this utility which plots the data graphically.    *
//  Started     : 10/01/2008                                                  *
//  Last Update : 22/01/2008                                                  *
//  Copyright   : (C) 2008 by MSWaters                                        *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef PRCGAW_HPP
#define PRCGAW_HPP

// System Includes

using  namespace  std;

#include <iostream>

// wxWindows Includes

#include <wx/wx.h>
#include <wx/tokenzr.h>

// Application Includes

#include "base/PrcBase.hpp"

// Local Constant Declarations


//*****************************************************************************

class PrcGaw : public PrcBase
{
  private:

    wxFileName  m_ofnResults; // The full simulator results file name

    // Functions for reformatting the results file for input to the viewer
    bool  bFormatFile ( void );
    bool  bFormatLine ( wxString & rosLine );
    bool  bFormatField( wxString & rosField );

  public:

    PrcGaw( void );
   ~PrcGaw( );

    bool  bSetResults( const wxString & rosFileName );

    const wxFileName & roGetResults( void ) { return( m_ofnResults ); }

    virtual  bool  bExec( void );
};

//*****************************************************************************

#endif // PRCGAW_HPP
